@@ -1,14 +1,19 @@
-# @(#)$Id: Serializer.pm 576 2009-06-09 23:23:46Z pjf $
+# @(#)$Id: Serializer.pm 1062 2011-10-23 01:23:45Z pjf $
 
 package CatalystX::Usul::View::Serializer;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 576 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.4.%d', q$Rev: 1062 $ =~ /\d+/gmx );
 use parent qw(CatalystX::Usul::View);
 
-use Class::C3;
+use CatalystX::Usul::Constants;
+use CatalystX::Usul::Functions qw(throw);
 use Data::Serializer;
+use MRO::Compat;
+use Safe;
+
+my $LB = chr 123;
 
 __PACKAGE__->config
    ( content_types => {
@@ -25,18 +30,45 @@ sub deserialize {
    $self->deserialize_attrs( $self->content_types->{ $s->{content_type} } );
 
    $process = sub {
-      return Data::Serializer->new( %{ $_[0] } )->deserialize( $_[1] );
+      if ( $_[ 0 ]->{serializer} eq q(Data::Dumper) ) {
+         my $code = $LB eq substr $_[ 1 ], 0, 1 ? q(+).$_[ 1 ] : $_[ 1 ];
+         my $compartment = Safe->new;
+
+         $compartment->permit_only( qw(anonhash anonlist const
+                                       leaveeval lineseq list null
+                                       padany pushmark refgen undef) );
+
+         return $compartment->reval( $code );
+      }
+
+      return Data::Serializer->new( %{ $_[ 0 ] } )->deserialize( $_[ 1 ] );
    };
 
    return $self->next::method( @rest, $process );
 }
 
 sub serialize {
-   my ($self, $attrs, $data) = @_;
+   my ($self, $attrs, $data) = @_; $attrs ||= {};
+
+   my $type = $attrs->{content_type} || NUL;
+
+   $attrs = $self->content_types->{ $type }
+      or throw "Unsupported content type ${type}";
 
    return Data::Serializer->new( %{ $attrs } )->serialize( $data );
 }
 
+# Private methods
+
+sub _unsupported_media_type {
+   my ($self, $c, $body) = @_;
+
+   $c->res->body( $body );
+   $c->res->content_type( q(text/plain) );
+   $c->res->status( 415 );
+   return TRUE;
+}
+
 1;
 
 __END__
@@ -49,7 +81,7 @@ CatalystX::Usul::View::Serializer - Serialize response to an XMLHttpRequest
 
 =head1 Version
 
-0.3.$Revision: 576 $
+0.4.$Revision: 1062 $
 
 =head1 Synopsis
 
