@@ -1,31 +1,47 @@
-# @(#)$Id: XML.pm 576 2009-06-09 23:23:46Z pjf $
+# @(#)$Id: XML.pm 1093 2011-12-30 00:24:43Z pjf $
 
 package CatalystX::Usul::View::XML;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 576 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.4.%d', q$Rev: 1093 $ =~ /\d+/gmx );
 use parent qw(CatalystX::Usul::View);
 
-use Class::C3;
 use XML::Simple;
+use MRO::Compat;
+
+__PACKAGE__->config
+   ( content_types     => {
+      'text/x-xml'     => { build_widgets => 0 },
+      'text/xml'       => { build_widgets => 1 }, },
+     deserialize_attrs => { ForceArray    => 0 }, );
 
-__PACKAGE__->config( deserialize_attrs => { ForceArray => 0 } );
 
 sub deserialize {
-   my ($self, @rest) = @_; my $process;
+   my ($self, @rest) = @_;
 
-   $process = sub { return XML::Simple->new( %{ $_[0] } )->xml_in( $_[1] ); };
+   my $process = sub { return XML::Simple->new( %{ $_[0] } )->xml_in( $_[1] ) };
 
    return $self->next::method( @rest, $process );
 }
 
 sub serialize {
-   my ($self, $attrs, $data) = @_;
+   my ($self, $attrs, $data) = @_; $attrs ||= {}; delete $attrs->{content_type};
 
    return XML::Simple->new( %{ $attrs } )->xml_out( $data );
 }
 
+# Private Methods
+
+sub _read_form_sources {
+   my ($self, $c) = @_; my $data = $self->next::method( $c );
+
+   $self->content_types->{ $c->stash->{content_type} }->{build_widgets}
+      and $self->_build_widgets( $c, { data => $data, skip_groups => 1 } );
+
+   return $data;
+}
+
 1;
 
 __END__
@@ -38,7 +54,7 @@ CatalystX::Usul::View::XML - Render XML response to an XMLHttpRequest
 
 =head1 Version
 
-0.3.$Revision: 576 $
+0.4.$Revision: 1093 $
 
 =head1 Synopsis
 
